summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/contactlist/kopetemetacontactlvi.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/contactlist/kopetemetacontactlvi.h')
-rw-r--r--kopete/kopete/contactlist/kopetemetacontactlvi.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/kopete/contactlist/kopetemetacontactlvi.h b/kopete/kopete/contactlist/kopetemetacontactlvi.h
index ba0e28f0..1b766b44 100644
--- a/kopete/kopete/contactlist/kopetemetacontactlvi.h
+++ b/kopete/kopete/contactlist/kopetemetacontactlvi.h
@@ -1,5 +1,5 @@
/*
- kopetemetacontactlvi.h - Kopete Meta Contact KListViewItem
+ kopetemetacontactlvi.h - Kopete Meta Contact TDEListViewItem
Copyright (c) 2004 by Richard Smith <kde@metafoo.co.uk>
Copyright (c) 2002-2003 by Olivier Goffart <ogoffart @ kde.org>
@@ -31,8 +31,8 @@
class TQVariant;
-class KAction;
-class KListAction;
+class TDEAction;
+class TDEListAction;
namespace Kopete
{
@@ -116,7 +116,7 @@ public:
bool isGrouped() const;
/**
* reimplemented from KListViewItem to take into account our alternate text storage
*/
virtual TQString text( int column ) const;
virtual void setText( int column, const TQString &text );
@@ -116,7 +116,7 @@ public:
bool isGrouped() const;
/**
- * reimplemented from KListViewItem to take into account our alternate text storage
+ * reimplemented from TDEListViewItem to take into account our alternate text storage
*/
virtual TQString text( int column ) const;